@@ -162,7 +162,6 @@ def schema_to_struct_code(struct_name, schema, definitions_schema):
     Generate code for the main class that maps to the given JSON schema.
     The main struct_name can include references to structures defined in
     definitions_schema, under "#/definitions/".
-    `See working examples in test. <https://github.com/loyada/typedpy/tree/master/tests/test_schema_to_code.py>`_
 
     Arguments:
         struct_name(str):
@@ -212,7 +211,7 @@ def schema_to_struct_code(struct_name, schema, definitions_schema):
 def schema_definitions_to_code(schema):
     """
     Generate code for the classes in the definitions that maps to the given JSON schema.
-    `See working example in test. <https://github.com/loyada/typedpy/tree/master/tests/test_schema_to_code.py>`_
+    `See working example in test_schema_to_code.py. <https://github.com/loyada/typedpy/tree/master/tests/test_schema_to_code.py>`_
 
     Arguments:
         schema(dict):
@@ -230,7 +229,6 @@ def schema_definitions_to_code(schema):
 def write_code_from_schema(schema, definitions_schema, filename, class_name):
     """
     Generate code from schema and write it to a file.
-    `See working examples in test. <https://github.com/loyada/typedpy/tree/master/tests/test_schema_to_code.py>`_
 
     Example:
 
