@@ -6,7 +6,7 @@ from typing import Dict
 from .commons import deep_get, raise_errs_if_needed
 from .versioned_mapping import VERSION_MAPPING, Versioned, convert_dict
 from .mappers import (
-    aggregate_deserialization_mappers,
+    DoNotSerialize, aggregate_deserialization_mappers,
     aggregate_serialization_mappers,
     mappers,
 )
@@ -752,6 +752,8 @@ def _get_mapped_value(mapper, key, items):
                 else [items.get(key)]
             )
             return key_mapper.func(*args)
+        elif key_mapper is DoNotSerialize:
+            return key_mapper
         elif not isinstance(key_mapper, (FunctionCall, str)):
             raise TypeError("mapper must have a FunctionCall or a string")
 
@@ -810,31 +812,30 @@ def serialize_internal(structure, mapper=None, compact=False, camel_case_convert
                 else _convert_to_camel_case_if_required(key, camel_case_convert)
             )
             mapped_value = _get_mapped_value(mapper, key, items_map)
-            the_field_definition = (
-                Anything if mapped_value else field_by_name.get(key, None)
-            )
-            sub_mapper = mapper.get(f"{key}._mapper", {})
-            result[mapped_key] = serialize_val(
-                the_field_definition,
-                key,
-                mapped_value or val,
-                mapper=sub_mapper,
-                camel_case_convert=camel_case_convert,
-            )
+            if mapped_value is not DoNotSerialize:
+                the_field_definition = (
+                    Anything if mapped_value else field_by_name.get(key, None)
+                )
+                sub_mapper = mapper.get(f"{key}._mapper", {})
+                result[mapped_key] = serialize_val(
+                    the_field_definition,
+                    key,
+                    mapped_value or val,
+                    mapper=sub_mapper,
+                    camel_case_convert=camel_case_convert,
+                )
     return result
 
 
 def serialize(value, *, mapper: Dict = None, compact=False, camel_case_convert=False):
     """
     Serialize an instance of :class:`Structure` to a JSON-like dict.
-    `See working examples in test. <https://github.com/loyada/typedpy/tree/master/tests/test_serialization.py>`_
 
     Arguments:
         value(:class:`Structure` or a field value with an obvious serialization):
             The value to be serialized - a structure instance, or a field value for which typedpy can deduce the
-             serialization.
+            serialization.
             In the general case, if you just need to serialize a field value, it's better to use serialize_field().
-
         mapper(dict): optional
              a dictionary where the key is the name of the attribute in the structure, and the value is name of the
              key to map its value to, or a :class:`FunctionCall` where the function is the transformation, and
@@ -850,6 +851,7 @@ def serialize(value, *, mapper: Dict = None, compact=False, camel_case_convert=F
         :param compact: in case there is a single attribute, it does not wrap it with a dictionary
         :param structure: an instance of :class:`Structure`
         :param mapper: a dict with the new key, by the attribute name
+
     """
     if not isinstance(value, (Structure, StructureReference)):
         if value is None or isinstance(value, (int, str, bool, float)):
